@@ -1,5 +1,5 @@
 package Net::Stripe::Charge;
-$Net::Stripe::Charge::VERSION = '0.27';
+$Net::Stripe::Charge::VERSION = '0.28';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -22,10 +22,12 @@ has 'balance_transaction' => (is => 'ro', isa => 'Maybe[Str]');
 has 'failure_message'     => (is => 'ro', isa => 'Maybe[Str]');
 has 'failure_code'        => (is => 'ro', isa => 'Maybe[Str]');
 has 'application_fee'     => (is => 'ro', isa => 'Maybe[Int]');
+has 'metadata'            => (is => 'rw', isa => 'Maybe[HashRef]');
 
 method form_fields {
     return (
         $self->fields_for('card'),
+        $self->form_fields_for_metadata(),
         map { $_ => $self->$_ }
             grep { defined $self->$_ }
                 qw/amount currency customer description application_fee/
@@ -45,7 +47,7 @@ Net::Stripe::Charge - represent an Charge object from Stripe
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 ATTRIBUTES
 
